==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationListBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyAutomationListBuilder extends PolicyAutomationListFluentImpl<PolicyAutomationListBuilder> implements VisitableBuilder<PolicyAutomationList,PolicyAutomationListBuilder>{
  public PolicyAutomationListBuilder() {
    this(false);
  }
  public PolicyAutomationListBuilder(Boolean validationEnabled) {
    this(new PolicyAutomationList(), validationEnabled);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PolicyAutomationList(), validationEnabled);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent,PolicyAutomationList instance) {
    this(fluent, instance, false);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent,PolicyAutomationList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PolicyAutomationListBuilder(PolicyAutomationList instance) {
    this(instance,false);
  }
  public PolicyAutomationListBuilder(PolicyAutomationList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  PolicyAutomationListFluent<?> fluent;
  Boolean validationEnabled;
  public PolicyAutomationList build() {
    PolicyAutomationList buildable = new PolicyAutomationList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> open-cluster-management-policy-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/PolicyAutomationListBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyAutomationListBuilder extends PolicyAutomationListFluent<PolicyAutomationListBuilder> implements VisitableBuilder<PolicyAutomationList,PolicyAutomationListBuilder>{
  public PolicyAutomationListBuilder() {
    this(false);
  }
  public PolicyAutomationListBuilder(Boolean validationEnabled) {
    this(new PolicyAutomationList(), validationEnabled);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PolicyAutomationList(), validationEnabled);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent,PolicyAutomationList instance) {
    this(fluent, instance, false);
  }
  public PolicyAutomationListBuilder(PolicyAutomationListFluent<?> fluent,PolicyAutomationList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PolicyAutomationList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PolicyAutomationListBuilder(PolicyAutomationList instance) {
    this(instance,false);
  }
  public PolicyAutomationListBuilder(PolicyAutomationList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PolicyAutomationList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  PolicyAutomationListFluent<?> fluent;
  Boolean validationEnabled;
  public PolicyAutomationList build() {
    PolicyAutomationList buildable = new PolicyAutomationList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
